package com.yidian.shenghuoquan.border.ui

import android.content.Intent
import androidx.activity.viewModels
import com.yidian.bcommon.constant.XEventConfig
import com.yidian.bcommon.constant.XRouterPathConstants
import com.yidian.bcommon.mvvm.BaseMvvmActivity
import com.yidian.shenghuoquan.border.R
import com.yidian.shenghuoquan.border.adapter.OrderConfirmCommodityListAdapter
import com.yidian.shenghuoquan.border.databinding.BorderActivityConfirmOrderBinding
import com.yidian.shenghuoquan.border.dto.CouponList
import com.yidian.shenghuoquan.border.dto.Shipping
import com.yidian.xarc.xevent.XBaseEvent
import com.yidian.xarc.xevent.XEventManager
import org.greenrobot.eventbus.Subscribe
import org.greenrobot.eventbus.ThreadMode

/**
 * 确认订单
 */
class ConfirmOrderActivity : BaseMvvmActivity<BorderActivityConfirmOrderBinding, ConfirmOrderViewModel>() {

  private val adapter by lazy { OrderConfirmCommodityListAdapter() }

  override val layoutId: Int = R.layout.border_activity_confirm_order

  override val vm: ConfirmOrderViewModel by viewModels()

  override fun initView() {
    XEventManager.register(this)
    subscribeUiEvent()
    initList()
    getIntentData(intent)
  }

  private fun initList() {
    binding.rvGoodsList.adapter = adapter
  }

  private fun getIntentData(intent: Intent?) {
    val paramsMap = intent?.getSerializableExtra(XRouterPathConstants.ParamsKey)
    if (paramsMap != null) {
      paramsMap as HashMap<String, String?>
      vm.requestConfirmOrderInfo(paramsMap)
    }
  }

  private fun subscribeUiEvent() {
    vm.goodsSuccessEvent.observe(this, {
      adapter.setList(it)
    })

  }

  override fun onDestroy() {
    super.onDestroy()
    XEventManager.unRegister(this)
  }

  @Subscribe(sticky = false, threadMode = ThreadMode.MAIN)
  fun onEvent(event: XBaseEvent?) {
    when (event?.name) {
      XEventConfig.CONFIRM_ORDER_CHOOSE_POINT_SUCCESS -> {
        // 选择自提点成功
        val point = event.body as Shipping
        vm.choosePickUpPointSuccess(point)
      }
      XEventConfig.CONFIRM_ORDER_CHOOSE_COUPON_SUCCESS -> {
        // 选择优惠券成功
        val coupon = event.body as CouponList
        vm.chooseVoucherSuccess(coupon)
      }
    }
  }

}
