package com.yidian.shenghuoquan.border.ui

import androidx.lifecycle.LiveData
import androidx.lifecycle.MutableLiveData
import com.yidian.bcommon.mvvm.BaseViewModel
import com.yidian.bcommon.utils.ToastUtils
import com.yidian.shenghuoquan.border.dto.CouponList
import com.yidian.shenghuoquan.border.dto.GoodsList
import com.yidian.shenghuoquan.border.dto.Shipping
import com.yidian.shenghuoquan.border.http.OrderRemoteDataSource

class ConfirmOrderViewModel : BaseViewModel() {

  private var originalAmount: Double = 0.00// 原价总和
  var couponAmount: Double = 0.00// 优惠券金额

  var selectedPickUpPoint = MutableLiveData<Shipping?>()// 自提点
  var receivingName = MutableLiveData<String>()// 收货人姓名
  var receivingPhone = MutableLiveData<String>()//收货人电话
  var selectedCoupon = MutableLiveData<CouponList>()// 选中的优惠券
  var couponsAvailableNum = MutableLiveData<Int>()// 可用优惠券数量
  var totalAmount = MutableLiveData(0.00)// 合计金额 = 原价 - 优惠
  var remark = MutableLiveData<String>()

  /**
   * 商品列表成功 Event
   */
  private val _goodsSuccessEvent = MutableLiveData<List<GoodsList>?>()
  val goodsSuccessEvent: LiveData<List<GoodsList>?> = _goodsSuccessEvent

  /**
   * 请求订单信息
   */
  fun requestConfirmOrderInfo(paramsMap: HashMap<String, String?>) {
//    val paramsMap = HashMap<String, String?>()
//    paramsMap["business_from"] = "2"
//    paramsMap["marketing_id"] = marketingId.toString()
    OrderRemoteDataSource.requestOrderConfirm(paramsMap) {
      if (it == null) {
        return@requestOrderConfirm
      }
      selectedPickUpPoint.value = it.shipping
      receivingName.value = it.shipping?.receiverName ?: ""
      receivingPhone.value = it.shipping?.receiverMobile ?: ""
      _goodsSuccessEvent.value = it.goodsList
      calculateOriginalAmount(it.goodsList)
      couponsAvailableNum.value = it.couponList?.size ?: 0 // 显示0张便于查看不能使用的优惠券

    }
  }

  /**
   * 计算商品原价 = 数量 * 单价
   */
  private fun calculateOriginalAmount(goodsList: List<GoodsList>?) {
    if (goodsList.isNullOrEmpty()) {
      return
    }
    goodsList.forEach {
      originalAmount = originalAmount.plus(it.price * it.goodsNum)
    }
    // 计算出合计
    calculateTotalAmount()
  }

  /**
   * 计算商品合计 = 原价 - 优惠
   */
  private fun calculateTotalAmount() {
    totalAmount.value = originalAmount - couponAmount
  }


  /**
   * 选择自提点
   */
  fun choosePickUpPoint() {
    // todo 带过去当前选中自提点
    ToastUtils.showLongSafe("去选择自提点")
  }

  fun choosePickUpPointSuccess(point: Shipping) {
    selectedPickUpPoint.value = point
  }

  /**
   * 选择代金券
   */
  fun chooseVoucher() {
    // todo 带过去当前选中优惠券
    ToastUtils.showLongSafe("去选择优惠券")
  }

  fun chooseVoucherSuccess(coupon: CouponList) {
    selectedCoupon.value = coupon
    couponAmount = coupon.amount?.toDouble() ?: 0.00
    // 重新计算相关金额
    calculateTotalAmount()
  }

  /**
   * 创建订单
   */
  fun createOrder() {
    val paramsMap = HashMap<String, String?>()
    paramsMap["business_from"] = "2"
    paramsMap["user_id"] = "510235230818"
    // todo 添加其他参数

    OrderRemoteDataSource.requestCreateOrder(paramsMap) {
      ToastUtils.showShort("创建订单成功${it?.orderId}")
    }
  }

  /**
   * 立即支付
   */
  fun payNow() {

  }

}
